---
title: Is there a way to render formulas? 
layout: page 
date: 2015-08-08
---

Yes: you can easily use MathJax with Urubu. Read more about it
[here](http://www.jandecaluwe.com/blog/urubu-formulas.html).

